@@ -90,8 +90,7 @@ class Basics:
             )
             return response
         except ResourceExistException as e:
-            print("project already exist!")
-            print("=======================================")
+            showlog.warning(e.error_msg)
             return
 
     def project_delete(
@@ -197,7 +196,7 @@ class Basics:
             extend_mode=True  # Shard扩展模式：默认是
     ):
         try:
-            res = self.dh.create_blob_topic(
+            self.dh.create_blob_topic(
                 project_name=project_name,
                 topic_name=topic_name,
                 shard_count=shard_count,
@@ -205,15 +204,16 @@ class Basics:
                 comment=comment,
                 extend_mode=extend_mode
             )
-            print("create topic success!")
-            print("=======================================")
+            res = {
+                "code": 0,
+                "message": "ok",
+                "data": ""
+            }
             return res
         except InvalidParameterException as e:
-            print(e)
-            print("=======================================")
+            showlog.warning(e.error_msg)
         except ResourceExistException as e:
-            print("topic already exist!")
-            print("=======================================")
+            showlog.warning(e.error_msg)
         except Exception as e:
             print(traceback.format_exc())
             sys.exit(-1)
@@ -422,6 +422,9 @@ def blob_topic_create(
         con_info: dict = None,  # 若指定，将优先使用
         env_file_name: str = 'aliyun.datahub.env',
 ):
+    """
+    创建topic
+    """
     # ---------------- 固定设置 ----------------
     if con_info is None:
         con_info = make_con_info(env_file_name=env_file_name)
@@ -430,12 +433,12 @@ def blob_topic_create(
     # ---------------- 固定设置 ----------------
     basic = Basics(con_info=con_info)
     return basic.blob_topic_create(
-        project_name=project_name,
-        topic_name=topic_name,
-        shard_count=shard_count,
-        life_cycle=life_cycle,
-        comment=comment,
-        extend_mode=extend_mode
+            project_name=project_name,
+            topic_name=topic_name,
+            shard_count=shard_count,
+            life_cycle=life_cycle,
+            comment=comment,
+            extend_mode=extend_mode
     )
 
 
@@ -470,8 +473,8 @@ def blob_records_add(
         if add_res['code'] == 0:
             return add_res
         else:
-            e = add_res['e']
-            if 'project does not exist' in e.error_msg and project_auto_create is True:
+            message = add_res['message']
+            if 'project does not exist' in message.error_msg and project_auto_create is True:
                 # 自动创建project
                 showlog.warning('project does not exist, auto creating...')
                 project_create_res = project_create(
@@ -485,7 +488,7 @@ def blob_records_add(
                 else:
                     showlog.warning('create project failed')
                     return project_create_res
-            elif 'topic does not exist' in e.error_msg and topic_auto_create is True:
+            elif 'topic does not exist' in message.error_msg and topic_auto_create is True:
                 # 自动创建topic
                 showlog.warning('topic does not exist, auto creating...')
                 blob_topic_create_res = blob_topic_create(
